==> ejc-tax-api-3.0.0-20210901.051356-152-sources.jar: com/ejianc/business/taxnew/vo/InvoiceDeducBillSubVO.java <==
package com.ejianc.business.taxnew.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 进项抵扣单子表
 * 
 * @author generator
 * 
 */
public class InvoiceDeducBillSubVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String invoiceCode; // 发票代码
    private String invoiceNumber; // 发票号码
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date invoiceDate; // 开票日期
    private java.math.BigDecimal invoiceMny; // 发票金额（不含税）
    private java.math.BigDecimal taxMny; // 税额
    private java.math.BigDecimal invoiceTaxMny; // 价税合计
    private String content; // 发票内容
    private String memo; // 抵扣申请子表备注
    private Long applySubId; // 抵扣申请子表id
    private java.math.BigDecimal actualDeducMny; // 实际抵扣金额
    private java.math.BigDecimal actualDeducTaxMny; // 实际抵扣税额
    private String canDeduc; // 是否可抵扣:汉字是、否
    private Long pid; // 主表抵扣单id
    private String thisMemo; // 本子表自己的备注
    private Long invoiceId; // 进项发票表id
    private String authDescription; // 认证状态 描述
    private Integer authState; // 认证状态：0未认证，1认证成功，2认证失败
    private Long orgId; // 组织id
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String applyCode; // 申请单编号
    private Long applyId; // 抵扣申请表id
    private Long invoiceType; // 发票类型:1、增值税专用发票，2、增值税普通发票，3、其他；
    /**
     * 单据编号
     */
    public String getCode() {
        return code;
    }

    /**
     * 单据编号
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 单据名称
     */
    public String getName() {
        return name;
    }

    /**
     * 单据名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 发票代码
     */
    public String getInvoiceCode() {
        return invoiceCode;
    }

    /**
     * 发票代码
     */
    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    /**
     * 发票号码
     */
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    /**
     * 发票号码
     */
    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    /**
     * 开票日期
     */
    public java.util.Date getInvoiceDate() {
        return invoiceDate;
    }

    /**
     * 开票日期
     */
    public void setInvoiceDate(java.util.Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    /**
     * 发票金额（不含税）
     */
    public java.math.BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    /**
     * 发票金额（不含税）
     */
    public void setInvoiceMny(java.math.BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }
    /**
     * 税额
     */
    public java.math.BigDecimal getTaxMny() {
        return taxMny;
    }

    /**
     * 税额
     */
    public void setTaxMny(java.math.BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    /**
     * 价税合计
     */
    public void setInvoiceTaxMny(java.math.BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }
    /**
     * 发票内容
     */
    public String getContent() {
        return content;
    }

    /**
     * 发票内容
     */
    public void setContent(String content) {
        this.content = content;
    }
    /**
     * 抵扣申请子表备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 抵扣申请子表备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 抵扣申请子表id
     */
    public Long getApplySubId() {
        return applySubId;
    }

    /**
     * 抵扣申请子表id
     */
    public void setApplySubId(Long applySubId) {
        this.applySubId = applySubId;
    }
    /**
     * 实际抵扣金额
     */
    public java.math.BigDecimal getActualDeducMny() {
        return actualDeducMny;
    }

    /**
     * 实际抵扣金额
     */
    public void setActualDeducMny(java.math.BigDecimal actualDeducMny) {
        this.actualDeducMny = actualDeducMny;
    }
    /**
     * 实际抵扣税额
     */
    public java.math.BigDecimal getActualDeducTaxMny() {
        return actualDeducTaxMny;
    }

    /**
     * 实际抵扣税额
     */
    public void setActualDeducTaxMny(java.math.BigDecimal actualDeducTaxMny) {
        this.actualDeducTaxMny = actualDeducTaxMny;
    }
    /**
     * 是否可抵扣:汉字是、否
     */
    public String getCanDeduc() {
        return canDeduc;
    }

    /**
     * 是否可抵扣:汉字是、否
     */
    public void setCanDeduc(String canDeduc) {
        this.canDeduc = canDeduc;
    }
    /**
     * 主表抵扣单id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 主表抵扣单id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 本子表自己的备注
     */
    public String getThisMemo() {
        return thisMemo;
    }

    /**
     * 本子表自己的备注
     */
    public void setThisMemo(String thisMemo) {
        this.thisMemo = thisMemo;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public String getAuthDescription() {
        return authDescription;
    }

    public void setAuthDescription(String authDescription) {
        this.authDescription = authDescription;
    }

    public Integer getAuthState() {
        return authState;
    }

    public void setAuthState(Integer authState) {
        this.authState = authState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(Long invoiceType) {
        this.invoiceType = invoiceType;
    }
}

==> ejc-tax-api-3.0.0-20210903.062713-156-sources.jar: com/ejianc/business/taxnew/vo/InvoiceDeducBillSubVO.java <==
package com.ejianc.business.taxnew.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 进项抵扣单子表
 * 
 * @author generator
 * 
 */
public class InvoiceDeducBillSubVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String invoiceCode; // 发票代码
    private String invoiceNumber; // 发票号码
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date invoiceDate; // 开票日期
    private java.math.BigDecimal invoiceMny; // 发票金额（不含税）
    private java.math.BigDecimal taxMny; // 税额
    private java.math.BigDecimal invoiceTaxMny; // 价税合计
    private String content; // 发票内容
    private String memo; // 抵扣申请子表备注
    private Long applySubId; // 抵扣申请子表id
    private java.math.BigDecimal actualDeducMny; // 实际抵扣金额
    private java.math.BigDecimal actualDeducTaxMny; // 实际抵扣税额
    private String canDeduc; // 是否可抵扣:汉字是、否
    private Long pid; // 主表抵扣单id
    private String thisMemo; // 本子表自己的备注
    private Long invoiceId; // 进项发票表id
    private String authDescription; // 认证状态 描述
    private Integer authState; // 认证状态：0未认证，1认证成功，2认证失败
    private Long orgId; // 组织id
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String applyCode; // 申请单编号
    private Long applyId; // 抵扣申请表id
    private Long invoiceType; // 发票类型:1、增值税专用发票，2、增值税普通发票，3、其他；
    private String supplierName; // 销方名称
    private Long supplierId; // 销方主键
    /**
     * 单据编号
     */
    public String getCode() {
        return code;
    }

    /**
     * 单据编号
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 单据名称
     */
    public String getName() {
        return name;
    }

    /**
     * 单据名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 发票代码
     */
    public String getInvoiceCode() {
        return invoiceCode;
    }

    /**
     * 发票代码
     */
    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    /**
     * 发票号码
     */
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    /**
     * 发票号码
     */
    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    /**
     * 开票日期
     */
    public java.util.Date getInvoiceDate() {
        return invoiceDate;
    }

    /**
     * 开票日期
     */
    public void setInvoiceDate(java.util.Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    /**
     * 发票金额（不含税）
     */
    public java.math.BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    /**
     * 发票金额（不含税）
     */
    public void setInvoiceMny(java.math.BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }
    /**
     * 税额
     */
    public java.math.BigDecimal getTaxMny() {
        return taxMny;
    }

    /**
     * 税额
     */
    public void setTaxMny(java.math.BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    /**
     * 价税合计
     */
    public void setInvoiceTaxMny(java.math.BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }
    /**
     * 发票内容
     */
    public String getContent() {
        return content;
    }

    /**
     * 发票内容
     */
    public void setContent(String content) {
        this.content = content;
    }
    /**
     * 抵扣申请子表备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 抵扣申请子表备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 抵扣申请子表id
     */
    public Long getApplySubId() {
        return applySubId;
    }

    /**
     * 抵扣申请子表id
     */
    public void setApplySubId(Long applySubId) {
        this.applySubId = applySubId;
    }
    /**
     * 实际抵扣金额
     */
    public java.math.BigDecimal getActualDeducMny() {
        return actualDeducMny;
    }

    /**
     * 实际抵扣金额
     */
    public void setActualDeducMny(java.math.BigDecimal actualDeducMny) {
        this.actualDeducMny = actualDeducMny;
    }
    /**
     * 实际抵扣税额
     */
    public java.math.BigDecimal getActualDeducTaxMny() {
        return actualDeducTaxMny;
    }

    /**
     * 实际抵扣税额
     */
    public void setActualDeducTaxMny(java.math.BigDecimal actualDeducTaxMny) {
        this.actualDeducTaxMny = actualDeducTaxMny;
    }
    /**
     * 是否可抵扣:汉字是、否
     */
    public String getCanDeduc() {
        return canDeduc;
    }

    /**
     * 是否可抵扣:汉字是、否
     */
    public void setCanDeduc(String canDeduc) {
        this.canDeduc = canDeduc;
    }
    /**
     * 主表抵扣单id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 主表抵扣单id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 本子表自己的备注
     */
    public String getThisMemo() {
        return thisMemo;
    }

    /**
     * 本子表自己的备注
     */
    public void setThisMemo(String thisMemo) {
        this.thisMemo = thisMemo;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public String getAuthDescription() {
        return authDescription;
    }

    public void setAuthDescription(String authDescription) {
        this.authDescription = authDescription;
    }

    public Integer getAuthState() {
        return authState;
    }

    public void setAuthState(Integer authState) {
        this.authState = authState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(Long invoiceType) {
        this.invoiceType = invoiceType;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
}
